Crate duskphantom_middle

Crate duskphantom_middle 

Modules

analysis
config
errors
ir
irgen
transform

Macros

define_graph_iterator
define_inst_type_enum
impl InstType enum automatically.
gen_common_code
Use this macro to generate some code for instruction to simplify the codesize. Make sure to use this macro in the impl Instruction block and the Instruction struct must have a field named manager which is an instance of InstManager.
impl_binary_inst
impl BinaryInst trait automatically.

Structs

Program

Functions

optimize